@@ -248,6 +248,10 @@ def clean_func(buf):
     pat = re.compile(r"""^(typedef|struct|enum)(\s|.|\n)*?;\s*""", re.MULTILINE) 
     buf=pat.sub('',buf)
 
+    #strip DECLS macros
+    pat = re.compile(r"""G_BEGIN_DECLS|BEGIN_LIBGTOP_DECLS""", re.MULTILINE) 
+    buf=pat.sub('',buf)
+
     #multiple whitespace
     pat = re.compile(r"""\s+""", re.MULTILINE) 
     buf=pat.sub(' ',buf)
@@ -259,7 +263,7 @@ def clean_func(buf):
 
     #associate *, &, and [] with type instead of variable
     #pat=re.compile(r'\s+([*|&]+)\s*(\w+)')
-    pat=re.compile(r' \s+ ([*|&]+) \s* (\w+)',re.VERBOSE)
+    pat=re.compile(r' \s* ([*|&]+) \s* (\w+)',re.VERBOSE)
     buf=pat.sub(r'\1 \2', buf)
     pat=re.compile(r'\s+ (\w+) \[ \s* \]',re.VERBOSE)
     buf=pat.sub(r'[] \1', buf)
