@@ -1,4 +1,24 @@
-/* -*- Mode: C; c-basic-offset: 4 -*- */
+/* -*- Mode: C; c-basic-offset: 4 -*-
+ * pygtk- Python bindings for the GTK toolkit.
+ * Copyright (C) 1998-2003  James Henstridge
+ *
+ *   gobjectmodule.c: wrapper for the gobject library.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
+ */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -8,6 +28,9 @@
 
 static PyObject *gerror_exc = NULL;
 
+static void pyg_flags_add_constants(PyObject *module, GType flags_type,
+				    const gchar *strip_prefix);
+
 /* -------------- GDK threading hooks ---------------------------- */
 
 /**
@@ -190,7 +213,9 @@ pyobject_free(gpointer boxed)
 {
     PyObject *object = boxed;
 
+    pyg_block_threads();
     Py_DECREF(object);
+    pyg_unblock_threads();
 }
 
 
@@ -675,7 +700,6 @@ pyg_object_set_property (GObject *object, guint property_id,
 	Py_DECREF(retval);
     } else {
 	PyErr_Print();
-	PyErr_Clear();
     }
 
     Py_DECREF(object_wrapper);
@@ -706,7 +730,6 @@ pyg_object_get_property (GObject *object, guint property_id,
 				 "O", py_pspec);
     if (retval == NULL || pyg_value_from_pyobject(value, retval) < 0) {
 	PyErr_Print();
-	PyErr_Clear();
     }
     Py_DECREF(object_wrapper);
     Py_DECREF(py_pspec);
@@ -1486,7 +1509,8 @@ get_handler_priority(gint *priority, PyObject *kwargs)
 			"keyword argument name is not a string");
 	return -1;
     }
-    if (!strcmp(PyString_AsString(key), "priority")) {
+
+    if (strcmp(PyString_AsString(key), "priority") != 0) {
 	PyErr_SetString(PyExc_TypeError,
 			"only 'priority' keyword argument accepted");
 	return -1;
@@ -1766,9 +1790,11 @@ pyg_enum_add_constants(PyObject *module, GType enum_type,
     GEnumClass *eclass;
     guint i;
 
-    /* a more useful warning */
     if (!G_TYPE_IS_ENUM(enum_type)) {
-	g_warning("`%s' is not an enum type", g_type_name(enum_type));
+	if (G_TYPE_IS_FLAGS(enum_type))	/* See bug #136204 */
+	    pyg_flags_add_constants(module, enum_type, strip_prefix);
+	else
+	    g_warning("`%s' is not an enum type", g_type_name(enum_type));
 	return;
     }
     g_return_if_fail (strip_prefix != NULL);
@@ -1803,9 +1829,11 @@ pyg_flags_add_constants(PyObject *module, GType flags_type,
     GFlagsClass *fclass;
     guint i;
 
-    /* a more useful warning */
     if (!G_TYPE_IS_FLAGS(flags_type)) {
-	g_warning("`%s' is not an flags type", g_type_name(flags_type));
+	if (G_TYPE_IS_ENUM(flags_type))	/* See bug #136204 */
+	    pyg_enum_add_constants(module, flags_type, strip_prefix);
+	else
+	    g_warning("`%s' is not an flags type", g_type_name(flags_type));
 	return;
     }
     g_return_if_fail (strip_prefix != NULL);
@@ -1843,7 +1871,7 @@ pyg_error_check(GError **error)
 	PyObject *exc_instance;
 	PyObject *d;
 	
-	pyg_unblock_threads();
+	pyg_block_threads();
 	
 	exc_instance = PyObject_CallFunction(gerror_exc, "z",
 					     (*error)->message);
@@ -2056,9 +2084,4 @@ initgobject(void)
     PyModule_AddObject(m, "TYPE_PARAM", pyg_type_wrapper_new(G_TYPE_PARAM));
     PyModule_AddObject(m, "TYPE_OBJECT", pyg_type_wrapper_new(G_TYPE_OBJECT));
     PyModule_AddObject(m, "TYPE_PYOBJECT", pyg_type_wrapper_new(PY_TYPE_OBJECT));
-
-    if (PyErr_Occurred()) {
-	PyErr_Print();
-	Py_FatalError("can't initialise module gobject");
-    }
 }
