@@ -1,4 +1,24 @@
-/* -*- Mode: C; c-basic-offset: 4 -*- */
+/* -*- Mode: C; c-basic-offset: 4 -*-
+ * pygtk- Python bindings for the GTK toolkit.
+ * Copyright (C) 1998-2003  James Henstridge
+ *
+ *   gtkmodule.c: module wrapping the GTK library
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -24,6 +44,7 @@ static struct _PyGtk_FunctionStruct functions = {
     VERSION,
 
     &PyGdkAtom_Type,  PyGdkAtom_New,
+    pygdk_rectangle_from_pyobject,
 };
 
 static void
@@ -170,8 +191,5 @@ init_gtk(void)
     pygdk_register_classes(d);
     pygdk_add_constants(m, "GDK_");
 
-    if (PyErr_Occurred())
-	Py_FatalError("can't initialise module _gtk");
-    
     gtk_timeout_add(100, python_do_pending_calls, NULL);
 }
